[−][src]Module ocaml::bigarray
bigarray contains wrappers for OCaml Bigarray values. These types can be used to transfer arrays of numbers between Rust
and OCaml directly without the allocation overhead of an array or list
Structs
| Array1 | OCaml Bigarray.Array1 type, , this introduces no
additional overhead compared to a |
Traits
| Kind | Bigarray kind |